from typing import List


def get_profile_length(profile: int) -> float: 
    """

    Args:
        profile (int): profile number

    Returns:
        float: length
    """
def get_edge_length(profile: int, edge: str) -> float: 
    """

    Args:
        profile (int): profile number
        edge (str): edge name

    Returns:
        float: length
    """
def get_all_caddy_element_ids() -> List[int]: 
    """

    Returns:
        List[int]: caddy elements
    """
