from typing import List


def display_simple_menu(items: List[str]) -> str: 
    """display a simple menu

    Args:
        items (List[str]): menu items

    Returns:
        str: item name
    """
