from typing import List


def create_material(name: str) -> int: 
    """

    Args:
        name (str): material name

    Returns:
        int: material ID
    """
def get_name(number: int) -> str: 
    """Get material name

    Args:
        number (int): element ID

    Returns:
        str: material name
    """
def set_name(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): a material name
    """
def get_group(number: int) -> str: 
    """get material group

    Args:
        number (int): element ID

    Returns:
        str: material group
    """
def set_group(number: int, value: str) -> None: 
    """set material group

    Args:
        number (int): element ID
        value (str): material group (name)
    """
def get_code(number: int) -> str: 
    """get material code

    Args:
        number (int): element ID

    Returns:
        str: material code
    """
def set_code(number: int, value: str) -> None: 
    """set material code

    Args:
        number (int): element ID
        value (str): material code
    """
def get_modulus_elasticity_1(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_modulus_elasticity_1(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_modulus_elasticity_2(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_modulus_elasticity_2(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_modulus_elasticity_3(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_modulus_elasticity_3(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_shear_modulus_1(number: int) -> float: 
    """_summary_

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_shear_modulus_1(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_shear_modulus_2(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_shear_modulus_2(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_price(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_price(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_price_type(number: int) -> str: 
    """

    Args:
        number (int): element ID

    Returns:
        str: _description_
    """
def set_price_type(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): _description_
    """
def get_thermal_conductivity(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_thermal_conductivity(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_heat_capacity(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_heat_capacity(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_u_min(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_u_min(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_u_max(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_u_max(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_fire_resistance_class(number: int) -> str: 
    """

    Args:
        number (int): element ID

    Returns:
        str: _description_
    """
def set_fire_resistance_class(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): _description_
    """
def get_smoke_class(number: int) -> str: 
    """

    Args:
        number (int): element ID

    Returns:
        str: _description_
    """
def set_smoke_class(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): _description_
    """
def get_drop_forming_class(number: int) -> str: 
    """

    Args:
        number (int): element ID

    Returns:
        str: _description_
    """
def set_drop_forming_class(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): _description_
    """
def get_burn_off_rate(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_burn_off_rate(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_weight(number: int) -> float: 
    """get material weight

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_weight(number: int, value: float) -> None: 
    """set material weight

    Args:
        number (int): element ID
        value (float): value
    """
def get_weight_type(number: int) -> str: 
    """gets the material weight type

    Args:
        number (int): element ID

    Returns:
        str: weight type
    """
def set_weight_type(number: int, value: str) -> None: 
    """sets the material weight type

    Args:
        number (int): element ID
        value (str): weight type
    """
def get_material_id(name: str) -> None: 
    """

    Args:
        name (str): material name
    """
def get_all_materials() -> List[int]: 
    """

    Returns:
        List[int]: all materials
    """
